@@ -21,7 +21,7 @@ require Exporter;
 	
 );
 
-$VERSION = '0.14';
+$VERSION = '0.1401';
 
 my %exported;
 sub import {
@@ -684,6 +684,12 @@ by integer conversion, which is a NOP on in-memory representations).  Which
 means that we need C code to all all the flavors, and our (autogenerated) C
 code is quite bulky and takes a lot of time to compile.
 
+On some machines (notably L<s390 or L<alpha>) C<double> may coincide with
+C<long double> (at least in size).  In such a situation, we assume that these
+types are completely identical, and do not even try to compile functions with
+C<long double> arguments.  (We use the corresponding functions with C<double>
+argments instead.)
+
 =head1 AUTHOR
 
 Ilya Zakharevich E<lt>ilyaz@cpan.orgE<gt>
